@@ -399,17 +399,6 @@ def get_streams(snowflake_conn, catalog, config, state):
     return resolve_catalog(discovered, streams_to_sync)
 
 
-def write_schema_message(catalog_entry, bookmark_properties=None):
-    key_properties = common.get_key_properties(catalog_entry)
-
-    singer.write_message(singer.SchemaMessage(
-        stream=catalog_entry.stream,
-        schema=catalog_entry.schema.to_dict(),
-        key_properties=key_properties,
-        bookmark_properties=bookmark_properties
-    ))
-
-
 def do_sync_incremental(snowflake_conn, catalog_entry, state, columns, replication_method):
     LOGGER.info('Stream %s is using incremental replication',
                 catalog_entry.stream)
@@ -421,7 +410,7 @@ def do_sync_incremental(snowflake_conn, catalog_entry, state, columns, replicati
         raise Exception(f'Cannot use INCREMENTAL replication for table ({catalog_entry.stream}) without a replication '
                         f'key.')
 
-    write_schema_message(catalog_entry=catalog_entry,
+    common.write_schema_message(catalog_entry=catalog_entry,
                          bookmark_properties=[replication_key])
 
     incremental.sync_table(snowflake_conn, catalog_entry,
@@ -434,7 +423,7 @@ def do_sync_full_table(snowflake_conn, catalog_entry, state, columns, replicatio
     LOGGER.info('Stream %s is using full table replication',
                 catalog_entry.stream)
 
-    write_schema_message(catalog_entry)
+    common.write_schema_message(catalog_entry)
 
     stream_version = common.get_stream_version(
         catalog_entry.tap_stream_id, state)
@@ -453,19 +442,18 @@ def do_sync_full_table(snowflake_conn, catalog_entry, state, columns, replicatio
     singer.write_message(singer.StateMessage(value=copy.deepcopy(state)))
 
 
-def do_sync_cdc(snowflake_conn, catalog_entry, state, columns, replication_method, stream_name):
+def do_sync_cdc(snowflake_conn, catalog_entry, state, columns, replication_method):
     LOGGER.info('Stream %s is using CDC replication', catalog_entry.stream)
 
-    write_schema_message(catalog_entry)
+    common.write_schema_message(catalog_entry)
 
     cdc.sync_table(snowflake_conn, catalog_entry, state,
-                   columns, replication_method, stream_name)
+                   columns, replication_method)
 
     singer.write_message(singer.StateMessage(value=copy.deepcopy(state)))
 
 
-def sync_streams(snowflake_conn, catalog, state, integration, replication_method):
-    stream_name = integration['table']
+def sync_streams(snowflake_conn, catalog, state, replication_method):
 
     for catalog_entry in catalog.streams:
         columns = list(catalog_entry.schema.properties.keys())
@@ -488,6 +476,7 @@ def sync_streams(snowflake_conn, catalog, state, integration, replication_method
 
         database_name = common.get_database_name(catalog_entry)
         schema_name = common.get_schema_name(catalog_entry)
+        stream_name = catalog_entry.table
 
         with metrics.job_timer('sync_table') as timer:
             timer.tags['database'] = database_name
@@ -504,7 +493,7 @@ def sync_streams(snowflake_conn, catalog, state, integration, replication_method
                     snowflake_conn, catalog_entry, state, columns, replication_method)
             elif replication_method == 'CDC':
                 do_sync_cdc(
-                    snowflake_conn, catalog_entry, state, columns, replication_method, stream_name)
+                    snowflake_conn, catalog_entry, state, columns, replication_method)
             else:
                 raise Exception(
                     'Only INCREMENTAL, FULL TABLE, and CDC replication methods are supported')
