@@ -15,6 +15,7 @@ LOGGER = singer.get_logger('macrometa_source_snowflake')
 class TooManyRecordsException(Exception):
     """Exception to raise when query returns more records than max_records"""
 
+
 def validate_config(config):
     """Validate configuration dictionary"""
     errors = []
@@ -42,6 +43,8 @@ def validate_config(config):
     return errors
 
 # PRIVATE KEY PATH
+
+
 def create_private_key_file(config: Dict) -> Dict:
     path_uuid = uuid.uuid4().hex
     try:
@@ -49,15 +52,18 @@ def create_private_key_file(config: Dict) -> Dict:
             path = f"/opt/snowflake/{path_uuid}/rsa_key.p8"
             private_key = Path(path)
             private_key.parent.mkdir(exist_ok=True, parents=True)
-            private_key.write_text(create_private_key_string(config['private_key_path']))
+            private_key.write_text(
+                create_private_key_string(config['private_key_path']))
             config['private_key_path'] = path
             LOGGER.info(f"Private key file created at: {path}")
 
     except Exception as e:
-        LOGGER.warn(f'Failed to create private key: /opt/snowflake/{path_uuid}/rsa_key.p8')
+        LOGGER.warn(
+            f'Failed to create private key: /opt/snowflake/{path_uuid}/rsa_key.p8')
 
     return config
 
+
 def delete_private_key_file(config: Dict) -> None:
     try:
         private_key = None
@@ -73,6 +79,7 @@ def delete_private_key_file(config: Dict) -> None:
     except Exception as e:
         LOGGER.warn(f"Failed to delete private key file: {e}")
 
+
 def create_private_key_string(private_key_string: str) -> str:
     private_key_list = []
     split_string = private_key_string.split("-----")
@@ -87,7 +94,6 @@ def create_private_key_string(private_key_string: str) -> str:
     return ''.join(private_key_list)
 
 
-
 class SnowflakeConnection:
     """Class to manage connection to snowflake data warehouse"""
 
@@ -130,7 +136,7 @@ class SnowflakeConnection:
 
         return None
 
-    def open_connection(self):
+    def open_connection(self, auto_commit=True):
         """Connect to snowflake database"""
         return snowflake.connector.connect(
             user=self.connection_config['user'],
@@ -140,16 +146,17 @@ class SnowflakeConnection:
             database=self.connection_config['dbname'],
             warehouse=self.connection_config['warehouse'],
             role=self.connection_config.get('role', None),
-            insecure_mode=self.connection_config.get('insecure_mode', False)
+            insecure_mode=self.connection_config.get('insecure_mode', False),
+            autocommit=auto_commit
             # Use insecure mode to avoid "Failed to get OCSP response" warnings
             # insecure_mode=True
         )
 
     # Retry logic has been removed as we were experiencing some issues
     # TODO: Revisit the retry logic which was implemented using backoff
-    def connect_with_backoff(self):
+    def connect_with_backoff(self, auto_commit=True):
         """Connect to snowflake database and retry automatically a few times if fails"""
-        return self.open_connection()
+        return self.open_connection(auto_commit)
 
     def query(self, query: Union[List[str], str], params: Dict = None, max_records=0):
         """Run a query in snowflake"""
