@@ -4,7 +4,7 @@
 import singer
 import macrometa_source_snowflake.sync_strategies.common as common
 
-LOGGER = singer.get_logger('macrometa_source_snowflake_snowflake')
+LOGGER = singer.get_logger('macrometa_source_snowflake')
 
 BOOKMARK_KEYS = {'last_pk_fetched', 'max_pk_values',
                  'version', 'initial_full_table_complete'}
