@@ -6,7 +6,7 @@ import singer
 from singer import metadata
 import macrometa_source_snowflake.sync_strategies.common as common
 
-LOGGER = singer.get_logger('macrometa_source_snowflake_snowflake')
+LOGGER = singer.get_logger('macrometa_source_snowflake')
 
 BOOKMARK_KEYS = {'replication_key', 'replication_key_value', 'version'}
 
